Module crate_data

Module crate_data 

Core rustdoc data types.

Structs

CrateData
The JSON documentation for a crate.
EagerCrateItemIndex
See CrateItemIndex for more information.
EagerCrateItemPaths
See CrateItemPaths for more information.
LazyCrateItemIndex
See CrateItemIndex for more information.
LazyCrateItemPaths
See CrateItemPaths for more information.

Enums

CrateItemIndex
The index of all the items in the crate.
CrateItemPaths
A mapping from the id of a type to its fully qualified path.